@@ -66,7 +66,7 @@ rmd_SCA <- function(Assessment, SCA2 = FALSE, ...) {
   # Assessment
   #### Pars and Fit
   if(SCA2) {
-    lead_par <- "## Assessment {.tabset}\n### Estimates and Model Fit\n"
+    lead_par <- rmd_meanR(header = "## Assessment {.tabset}\n### Estimates and Model Fit\n")
   } else {
     lead_par <- c(rmd_R0(header = "## Assessment {.tabset}\n### Estimates and Model Fit\n"), rmd_h())
   }
@@ -124,7 +124,7 @@ profile_likelihood_SCA <- function(Assessment, ...) {
   joint_profile <- !exists("profile_par")
 
   profile_fn <- function(i, Assessment, params, map) {
-    params$log_R0 <- log(profile_grid[i, 1]  * Assessment@obj$env$data$rescale)
+    params$R0x <- log(profile_grid[i, 1]  * Assessment@obj$env$data$rescale)
     if(Assessment@info$data$SR_type == "BH") {
       params$transformed_h <- logit((profile_grid[i, 2] - 0.2)/0.8)
     } else {
@@ -132,9 +132,9 @@ profile_likelihood_SCA <- function(Assessment, ...) {
     }
 
     if(joint_profile) {
-      map$log_R0 <- map$transformed_h <- factor(NA)
+      map$R0x <- map$transformed_h <- factor(NA)
     } else {
-      if(profile_par == "R0") map$log_R0 <- factor(NA) else map$transformed_h <- factor(NA)
+      if(profile_par == "R0") map$R0x <- factor(NA) else map$transformed_h <- factor(NA)
     }
     obj2 <- MakeADFun(data = Assessment@info$data, parameters = params, map = map, random = Assessment@obj$env$random,
                       inner.control = Assessment@info$inner.control, DLL = "MSEtool", silent = TRUE)
@@ -262,13 +262,13 @@ profile_likelihood_SCA2 <- function(Assessment, ...) {
 
   params <- Assessment@info$params
   map <- Assessment@obj$env$map
-  map$log_meanR <- factor(NA)
+  map$meanRx <- factor(NA)
 
   profile_fn <- function(i, Assessment, params, map) {
 
-    params$log_meanR <- log(meanR[i] * Assessment@obj$env$data$rescale)
+    params$meanRx <- log(meanR[i] * Assessment@obj$env$data$rescale)
     if(length(Assessment@opt$par) == 1) {
-      nll <- Assessment@obj$fn(params$log_meanR)
+      nll <- Assessment@obj$fn(params$meanRx)
     } else {
 
       obj2 <- MakeADFun(data = Assessment@info$data, parameters = params, map = map, random = Assessment@obj$env$random,
