@@ -29,11 +29,13 @@ summary_SCA_Pope <- function(Assessment) {
     model_estimates <- summary(SD)[rownames(summary(SD)) != "log_rec_dev" & rownames(summary(SD)) != "log_early_rec_dev", ]
     model_estimates <- model_estimates[!is.na(model_estimates[, 2]) && model_estimates[, 2] > 0, ]
 
-    if(length(SE_Dev) == 0) SE_Dev <- rep(NA, length(Dev))
-    dev_estimates <- cbind(Dev, SE_Dev)
-    rownames(dev_estimates) <- paste0("log_rec_dev_", names(Dev))
+    if(length(Dev) > 0) {
+      if(length(SE_Dev) == 0) SE_Dev <- rep(NA, length(Dev))
+      dev_estimates <- cbind(Dev, SE_Dev)
+      rownames(dev_estimates) <- paste0("log_rec_dev_", names(Dev))
 
-    model_estimates <- rbind(model_estimates, dev_estimates)
+      model_estimates <- rbind(model_estimates, dev_estimates)
+    }
   } else {
     model_estimates <- SD
   }
@@ -112,22 +114,16 @@ retrospective_SCA_Pope <- function(Assessment, nyr) {
   retro_est <- array(NA, dim = c(nyr+1, dim(SD_nondev)))
   dimnames(retro_est) <- list(Peel = 0:nyr, Var = rownames(SD_nondev), Value = c("Estimate", "Std. Error"))
 
-  SD <- NULL
-  rescale <- info$rescale
-
-  data_ret <- info$data
-  params_ret <- info$params
-
-  for(i in 0:nyr) {
+  lapply_fn <- function(i, info, obj) {
     n_y_ret <- n_y - i
-    data_ret$n_y <- n_y_ret
-    data_ret$C_hist <- info$data$C_hist[1:n_y_ret]
-    data_ret$I_hist <- info$data$I_hist[1:n_y_ret]
-    data_ret$CAA_hist <- info$data$CAA_hist[1:n_y_ret, ]
-    data_ret$CAA_n <- info$data$CAA_n[1:n_y_ret]
-    data_ret$est_rec_dev <- info$data$est_rec_dev[1:n_y_ret]
+    info$data$n_y <- n_y_ret
+    info$data$C_hist <- info$data$C_hist[1:n_y_ret]
+    info$data$I_hist <- info$data$I_hist[1:n_y_ret]
+    info$data$CAA_hist <- info$data$CAA_hist[1:n_y_ret, ]
+    info$data$CAA_n <- info$data$CAA_n[1:n_y_ret]
+    info$data$est_rec_dev <- info$data$est_rec_dev[1:n_y_ret]
 
-    params_ret$log_rec_dev <- rep(0, n_y_ret)
+    info$params$log_rec_dev <- rep(0, n_y_ret)
 
     map <- obj$env$map
     if(any(names(map) == "log_rec_dev")) {
@@ -135,7 +131,7 @@ retrospective_SCA_Pope <- function(Assessment, nyr) {
       map$log_rec_dev <- factor(new_map[new_map > 0])
     }
 
-    obj2 <- MakeADFun(data = data_ret, parameters = params_ret, map = map, random = obj$env$random,
+    obj2 <- MakeADFun(data = info$data, parameters = info$params, map = map, random = obj$env$random,
                       inner.control = info$inner.control, DLL = "MSEtool", silent = TRUE)
     mod <- optimize_TMB_model(obj2, info$control)
     opt2 <- mod[[1]]
@@ -147,16 +143,6 @@ retrospective_SCA_Pope <- function(Assessment, nyr) {
                                   vul = report$vul, SR = info$data$SR_type)
 
       report <- c(report, ref_pt)
-      if(info$rescale != 1) {
-        vars_div <- c("R0", "B", "E", "CAApred", "CN", "Cpred", "N", "VB",
-                      "R", "MSY", "VBMSY", "RMSY", "BMSY", "EMSY", "VB0",
-                      "B0", "E0", "N0")
-        vars_mult <- "Brec"
-        var_trans <- c("R0", "q")
-        fun_trans <- c("/", "*")
-        fun_fixed <- c("log", NA)
-        rescale_report(vars_div, vars_mult, var_trans, fun_trans, fun_fixed)
-      }
 
       U <- c(report$U, rep(NA, i + 1))
       U_UMSY <- U/report$UMSY
@@ -167,14 +153,17 @@ retrospective_SCA_Pope <- function(Assessment, nyr) {
       VB <- c(report$E, rep(NA, i))
       #log_rec_dev <- c(report$log_rec_dev, rep(NA, i + 1))
 
-      retro_ts[i+1, , ] <- cbind(U, U_UMSY, SSB, SSB_SSBMSY, SSB_SSB0, R, VB)
-      retro_est[i+1, , ] <- summary(SD)[rownames(summary(SD)) != "log_rec_dev" & rownames(summary(SD)) != "log_early_rec_dev", ]
+      retro_ts[i+1, , ] <<- cbind(U, U_UMSY, SSB, SSB_SSBMSY, SSB_SSB0, R, VB)
+      retro_est[i+1, , ] <<- summary(SD)[rownames(summary(SD)) != "log_rec_dev" & rownames(summary(SD)) != "log_early_rec_dev", ]
 
-    } else {
-      message("Non-convergence when peel = ", i, " (years of data removed).")
+      return(SD$pdHess)
     }
+    return(FALSE)
   }
 
+  conv <- vapply(0:nyr, lapply_fn, logical(1), info = info, obj = obj)
+  if(any(!conv)) warning("Peels that did not converge: ", paste0(which(!conv) - 1, collapse = " "))
+
   retro <- new("retro", Model = Assessment@Model, Name = Assessment@Name, TS_var = TS_var, TS = retro_ts,
                Est_var = dimnames(retro_est)[[2]], Est = retro_est)
   attr(retro, "TS_lab") <- c("Harvest rate", expression(U/U[MSY]), "Spawning biomass", expression(SSB/SSB[MSY]), "Spawning depletion",
