@@ -16,14 +16,19 @@ Type cDD(objective_function<Type> *obj) {
   DATA_INTEGER(k);
   DATA_SCALAR(wk);
   DATA_VECTOR(C_hist);
+  DATA_SCALAR(dep);
   DATA_SCALAR(rescale);
-  DATA_VECTOR(I_hist);
+  DATA_MATRIX(I_hist);
+  DATA_IVECTOR(I_units);
+  DATA_MATRIX(I_sd);
   DATA_STRING(SR_type);
   DATA_INTEGER(nitF);
-
+  DATA_VECTOR(I_lambda);
+  DATA_INTEGER(nsurvey);
+  DATA_INTEGER(fix_sigma);
   DATA_INTEGER(state_space);
 
-  PARAMETER(log_R0);
+  PARAMETER(R0x);
   PARAMETER(transformed_h);
   PARAMETER(F_equilibrium);
   PARAMETER(log_sigma);
@@ -35,7 +40,7 @@ Type cDD(objective_function<Type> *obj) {
     h = 0.8 * invlogit(transformed_h);
   } else h = exp(transformed_h);
   h += 0.2;
-  Type R0 = exp(log_R0)/rescale;
+  Type R0 = exp(R0x)/rescale;
   Type sigma = exp(log_sigma);
   Type tau = exp(log_tau);
   int SR_type2 = SR_type == "BH";
@@ -71,7 +76,7 @@ Type cDD(objective_function<Type> *obj) {
   vector<Type> F(ny);
   vector<Type> Z(ny);
   vector<Type> Cpred(ny);
-  vector<Type> Ipred(ny);
+  matrix<Type> Ipred(ny,nsurvey);
 
   vector<Type> BPRinf(ny);
   vector<Type> Rec_dev(ny-k);
@@ -86,7 +91,10 @@ Type cDD(objective_function<Type> *obj) {
   N(0) = Req/(F_equilibrium + M);
   for(int tt=0;tt<k;tt++) R(tt) = Req;
 
-  Type penalty = 0;
+  Type Ceqpred = F_equilibrium * B(0);
+
+  Type penalty = 0; // Pentalty to likelihood for high F > max_F
+  Type prior = -dnorm_(log(B(0)/B0), log(dep), Type(0.01), true); // Penalty for initial depletion to get corresponding F
 
   for(int tt=0; tt<ny; tt++) {
     Type F_start = CppAD::CondExpLe(C_hist(tt), Type(1e-8), Type(0), -log(1 - C_hist(tt)/B(tt)));
@@ -111,21 +119,31 @@ Type cDD(objective_function<Type> *obj) {
   }
 
   //--ARGUMENTS FOR NLL
-  Type q = calc_q(I_hist, B);
-  for(int tt=0;tt<ny;tt++) Ipred(tt) = q * B(tt);
+  vector<Type> q = calc_q(I_hist, B, N, Ipred, nsurvey, I_units);
 
   // Objective function
   //creates storage for jnll and sets value to 0
-  vector<Type> nll_comp(2);
+  vector<Type> nll_comp(nsurvey+1);
   nll_comp.setZero();
 
-  for(int tt=0;tt<ny;tt++) if(!R_IsNA(asDouble(I_hist(tt)))) nll_comp(0) -= dnorm(log(I_hist(tt)), log(Ipred(tt)), sigma, true);
+  for(int sur=0;sur<nsurvey;sur++) {
+    for(int tt=0;tt<ny;tt++) {
+      if(I_lambda(sur) > 0 && !R_IsNA(asDouble(I_hist(tt,sur)))) {
+        if(fix_sigma) {
+          nll_comp(sur) -= dnorm_(log(I_hist(tt,sur)), log(Ipred(tt,sur)), I_sd(tt,sur), true);
+        } else {
+          nll_comp(sur) -= dnorm(log(I_hist(tt,sur)), log(Ipred(tt,sur)), sigma, true);
+        }
+      }
+    }
+    nll_comp(sur) *= I_lambda(sur);
+  }
   if(state_space) {
-    for(int tt=0;tt<log_rec_dev.size();tt++) nll_comp(1) -= dnorm(log_rec_dev(tt), Type(0), tau, true);
+    for(int tt=0;tt<log_rec_dev.size();tt++) nll_comp(nsurvey) -= dnorm(log_rec_dev(tt), Type(0), tau, true);
   }
 
   //Summing individual jnll and penalties
-  Type nll = nll_comp.sum() + penalty;
+  Type nll = nll_comp.sum() + penalty + prior;
 
   //-------REPORTING-------//
   ADREPORT(R0);
@@ -133,13 +151,14 @@ Type cDD(objective_function<Type> *obj) {
   ADREPORT(q);
   if(CppAD::Variable(log_sigma)) ADREPORT(sigma);
   if(CppAD::Variable(log_tau)) ADREPORT(tau);
-  REPORT(sigma);
+  if(!fix_sigma) REPORT(sigma);
   if(state_space) REPORT(tau);
   REPORT(nll);
   REPORT(Arec);
   REPORT(Brec);
   REPORT(BPR0);
   REPORT(Cpred);
+  REPORT(Ceqpred);
   REPORT(Ipred);
   REPORT(q);
   REPORT(B);
@@ -158,6 +177,7 @@ Type cDD(objective_function<Type> *obj) {
   REPORT(Rec_dev);
   REPORT(nll_comp);
   REPORT(penalty);
+  REPORT(prior);
 
   return nll;
 }
